@@ -45,33 +45,33 @@ raw_grid <- function(data, well,
     platemap <- plate_map_grid(data, well, plate_id)
 
     if (plate == 96) {
-	# produce a plate map in ggplot (96-well format)
-	plt<- plt96(platemap) +
-	    theme_bw() +
-	    theme(panel.margin.x = unit(1, "lines"),
-	    panel.margin.y = unit(0.5, "lines")) + # increase spacing between facets
-	    facet_wrap(~plate_label,
-			ncol = ncols,
-			scales = 'free')
+    # produce a plate map in ggplot (96-well format)
+    plt<- plt96(platemap) +
+        theme_bw() +
+        theme(panel.spacing.x = unit(1, "lines"),
+        panel.spacing.y = unit(0.5, "lines")) + # increase spacing between facets
+        facet_wrap(~plate_label,
+            ncol = ncols,
+            scales = 'free')
 
     } else if (plate == 384L){
-	# produce a plate map in ggplot (384-well format)
-	plt <- plt384(platemap) +
-	    theme_bw() +
-	    theme(panel.margin.x = unit(1, "lines"),
-	    panel.margin.y = unit(0.5, "lines")) + # increase spacing between facets
-	    facet_wrap(~plate_label,
-			ncol = ncols,
-			scales = 'free')
+    # produce a plate map in ggplot (384-well format)
+    plt <- plt384(platemap) +
+        theme_bw() +
+        theme(panel.spacing.x = unit(1, "lines"),
+        panel.spacing.y = unit(0.5, "lines")) + # increase spacing between facets
+        facet_wrap(~plate_label,
+            ncol = ncols,
+            scales = 'free')
 
     } else if (plate == 1536L){
-	plt <- plt1536(platemap) +
-	    theme_bw() +
-	    theme(panel.margin.x = unit(1, "lines"),
-	    panel.margin.y = unit(0.5, "lines")) + # increase spacing between facets
-	    facet_wrap(~plate_label,
-			ncol = ncols,
-			scales = 'free')
+    plt <- plt1536(platemap) +
+        theme_bw() +
+        theme(panel.spacing.x = unit(1, "lines"),
+        panel.spacing.y = unit(0.5, "lines")) + # increase spacing between facets
+        facet_wrap(~plate_label,
+            ncol = ncols,
+            scales = 'free')
 
     } else stop("Invalid argument for 'plate'. \nOption: 96 or 384.",
             call. = FALSE)
