@@ -45,31 +45,31 @@ z_grid <- function(data, well,
     platemap <- plate_map_grid_scale(data, well, plate_id, each)
 
     if (plate == 96L){
-	plt <- plt96(platemap) +
-	    theme_bw() +
-	    theme(panel.margin.x = unit(1, "lines"),
-		panel.margin.y = unit(0.5, "lines")) + # increase spacing between facets
-	    facet_wrap(~plate_label,
-			ncol = ncols,
-			scales = 'free')
+        plt <- plt96(platemap) +
+                theme_bw() +
+                theme(panel.spacing.x = unit(1, "lines"),
+            panel.spacing.y = unit(0.5, "lines")) + # increase spacing between facets
+                facet_wrap(~plate_label,
+            ncol = ncols,
+            scales = 'free')
     } else if (plate == 384L){
-	plt <- plt384(platemap) +
-	    theme_bw() +
-	    theme(panel.margin.x = unit(1, "lines"),
-		panel.margin.y = unit(1, "lines")) + # increase spacing between facets
-	    facet_wrap(~plate_label,
-			ncol = ncols,
-			scales = 'free')
+        plt <- plt384(platemap) +
+            theme_bw() +
+            theme(panel.spacing.x = unit(1, "lines"),
+        panel.spacing.y = unit(1, "lines")) + # increase spacing between facets
+            facet_wrap(~plate_label,
+        ncol = ncols,
+        scales = 'free')
     } else if (plate == 1536L) {
-	plt <- plt1536(platemap) +
-		theme_bw() +
-		theme(panel.margin.x = unit(1, "lines"),
-		    panel.margin.y = unit(1, "lines")) + # increase spacing between facets
-		facet_wrap(~plate_label,
-			    ncol = ncols,
-			    scales = "free")
+        plt <- plt1536(platemap) +
+            theme_bw() +
+            theme(panel.spacing.x = unit(1, "lines"),
+                panel.spacing.y = unit(1, "lines")) + # increase spacing between facets
+            facet_wrap(~plate_label,
+                ncol = ncols,
+                scales = "free")
     } else stop("Invalid argument for 'plate'. \nOptions: 96 or 384.",
-		call. = FALSE)
+    call. = FALSE)
 
     return(plt)
 }
